@@ -30,7 +30,7 @@ class S3FineView(View):
         return csrf_exempt(view)
 
     def post(self, request, *args, **kwargs):
-        request_dict = request.DATA
+        request_dict = request.POST
 
         if 'filename' not in request_dict or 'mime_type' not in request_dict:
             return HttpResponseBadRequest(
